# Extra encodings for Python 

## Update 1.3.2
----
Gen2 and LTF64 released for beta and ichor has progressed for US keyboard.\
Updated import process for beta for technical reasons\
Added support for Python 3.6\


## Plans:
----
Adding more encodings/decodings\
Work on a version for python 3.4 and older (For whoever still uses that)\
Make a Gui (tkinter) for the encoder\
Add Binary encodings\


## Notes
----
Currently we only support all characters on a US keyboard for all encoding types and a computer that runs a standard os like Win32/64 , macOS (Not tested), Linux Debian,Ubuntu and distros based on them.

## Decodings and encodings:
----
Ichor (Not fully finshed)\
Gen2\
LTF-64\
GTX2 (Raw encoder exists in ciphers.py but not in beta yet)

## How to import
----
`from extra_Encodings.extra_Encodings_pkg.encodings import *` \
To import beta versions\
`from extra_Encodings.extra_Encodings_pkg.encodingsbeta import *`\
To import raw encoder for Gen2 and dicts for ichor\
`from extra_Encodings.extra_Encodings_pkg.ciphers import *`